#!/bin/bash

#this script is divided in 4 main parts:

# 1. preparation
# 2. installation
# 3. propagation
# 4. annullation

export vo=$1
export action=$2
export flag=$3
export host=$4

###############################################################################
#Preparation() ....of the environmental framework
#
#Notes: this routine does:
# 0. Get input variables: (1)vo (2)action (3)name-of-flag (4)Host_name_of_service.
# 1.  If these variable are not set exit 
# 2. checks whether the configuration file is present in the expected position
# 3. read from this configuration file the value of some variable and set the corresponding environment
# 4. cd on the LOCAL ROOT DIRECTORY
#
# This part shouldn't change
################################################################################
preparation()
{
export in_file=${LCG_LOCATION}/etc/spark.conf
if [ "${vo}x" == "x" ];then
    echo "VO not defined"
    exit -1
fi
if [ "${flag}x" == "x" ];then
    echo "Flag not defined"
    exit -1
fi
if [ "${host}x" == "x" ];then
    echo "Host Name of the service not defined"
    exit -1
fi
if [ "${action}x" == "x" ];then
    echo "action not defined"
    exit -1
fi

if [ ! -f $in_file ]; then
    echo "No configuration file present"
    exit 1 
fi
export EDG_FLAG_DIR=`/bin/grep "^${vo}_flagdir" $in_file | /usr/bin/awk -F"=" '{print $2}'`/
export LOCAL_INSTALL_DIR=`/bin/grep "^${vo}_locdir" $in_file | /usr/bin/awk -F"=" '{print $2}'`/
cd ${LOCAL_INSTALL_DIR}
echo "@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@"
}


################################################################################
# Install_script() is the user provided part of this template: It should install your 
#software locally (`pwd`) as root directory. Writing this part the user MUST imagine 
#to be in a local DeskTop and to install software under a specified directory in a relocatable way.
# It should also contains a kind of pre-validation part informing whether the 
#local installation went OK (return 0) or some problem happened (return a non-0 code)
################################################################################
install_script()
{
echo "**** This is the local root exp-soft-area **** " `pwd`
DAY=`date "+%A-%d-%m-2004"`
mkdir -p $DAY/pacman
cd $DAY/pacman
wget http://physics.bu.edu/~youssef/pacman/sample_cache/tarballs/pacman-2.121.tar.gz
tar zxvf pacman-2.121.tar.gz 
rm -rf pacman-2.121.tar.gz
cd pac*
source setup.sh
}
################################################################################
# Propagation() Is the final part of the installation script.
# If the local installation went OK the ESM must trigger the propagation of this software 
# in every WN of the site through the Tank&Spark mechanismthe user provided part of this template: It should install your 
#software locally (`pwd`) as root directory. Writing this part the user MUST imagine 
#to be in a local DeskTop and must install software where it is.
#
# This part shouldn't change
##################################################################################
propagation()
{
    if [ ! $? -eq "0" ]; then
	echo "Error on the local experiment software installation process" >&2
	exit 1
    fi
    ${LCG_LOCATION}/sbin/lcg-spark -h http://$host:18085 -a $action -f $flag --vo $vo   
}


################################################################################
# annull() is another user provided part of this template: It should remove the software previously installed under the main directory (LOCAL_INSTALL_DIR)

################################################################################
annull()
{
cd $LOCAL_INSTALL_DIR
rm -rf $DAY
}



# The script it self: main.....

preparation
install_script
propagation
if [ ! $? -eq "0" ]; then
echo "An error occur in the tank&spark mechanism: rolling-back the change"
#the propagation failed in somehow-please see the output of the JDL job
annull
else
 echo "The installation/removal has been  propagated to other WNs and you will be advertised once all WNs get updated if you decide to be notified through the -n option set"
fi
